<!DOCTYPE TS><TS>
<context>
    <name>String::DayOfWeek</name>
    <message>
        <source>MON</source>
        <translation>月</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation>火</translation>
    </message>
    <message>
        <source>WED</source>
        <translation>水</translation>
    </message>
    <message>
        <source>THU</source>
        <translation>木</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation>金</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation>土</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation>日</translation>
    </message>
</context>
<context>
    <name>String::WeatherType</name>
    <message>
        <source>Cloudy</source>
        <translation>曇り</translation>
    </message>
    <message>
        <source>Mostly Cloudy</source>
        <translation>ほぼ曇り</translation>
    </message>
    <message>
        <source>Partly Cloudy</source>
        <translation>一時曇り</translation>
    </message>
    <message>
        <source>Light Rain</source>
        <translation>小雨</translation>
    </message>
    <message>
        <source>Showers</source>
        <translation>にわか雨</translation>
    </message>
    <message>
        <source>Rain</source>
        <translation>雨</translation>
    </message>
    <message>
        <source>AM Showers</source>
        <translation>午前中 雨</translation>
    </message>
    <message>
        <source>Fog</source>
        <translation>霧</translation>
    </message>
    <message>
        <source>Few Showers</source>
        <translation>まれににわか雨</translation>
    </message>
    <message>
        <source>Mostly Sunny</source>
        <translation>ほぼ晴れ</translation>
    </message>
    <message>
        <source>Sunny</source>
        <translation>晴れ</translation>
    </message>
    <message>
        <source>Scattered Flurries</source>
        <translation>ときどき通り雨</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun</source>
        <translation>午前 曇り/午後 晴れ</translation>
    </message>
    <message>
        <source>Isolated T-Storms</source>
        <translation>一時雷雨</translation>
    </message>
    <message>
        <source>Scattered Thunderstorms</source>
        <translation>ときどき雷雨</translation>
    </message>
    <message>
        <source>PM Showers</source>
        <translation>午後 にわか雨</translation>
    </message>
    <message>
        <source>PM Showers/Wind</source>
        <translation>午後 にわか雨/強風</translation>
    </message>
    <message>
        <source>Rain/Snow Showers</source>
        <translation>にわか雨/にわか雪</translation>
    </message>
    <message>
        <source>Few Snow Showers</source>
        <translation>まれににわか雪</translation>
    </message>
    <message>
        <source>Cloudy/Wind</source>
        <translation>曇り/強風</translation>
    </message>
    <message>
        <source>Flurries/Wind</source>
        <translation>通り雨/強風</translation>
    </message>
    <message>
        <source>Mostly Cloudy/Windy</source>
        <translation>ほぼ曇り/強風</translation>
    </message>
    <message>
        <source>Rain/Thunder</source>
        <translation>雨/雷</translation>
    </message>
    <message>
        <source>Partly Cloudy/Windy</source>
        <translation>一時曇り/強風</translation>
    </message>
    <message>
        <source>AM Rain/Snow Showers</source>
        <translation>午前中 にわか雨/にわか雪</translation>
    </message>
    <message>
        <source>Light Rain/Wind</source>
        <translation>弱い雨/強風</translation>
    </message>
    <message>
        <source>Showers/Wind</source>
        <translation>にわか雨/強風</translation>
    </message>
    <message>
        <source>Mostly Sunny/Wind</source>
        <translation>ほぼ晴れ/強風</translation>
    </message>
    <message>
        <source>Flurries</source>
        <translation>通り雨</translation>
    </message>
    <message>
        <source>Rain/Wind</source>
        <translation>雨/強風</translation>
    </message>
    <message>
        <source>Sct Flurries/Wind</source>
        <translation>一時にわか雨/強風</translation>
    </message>
    <message>
        <source>Sct Strong Storms</source>
        <translation>一時強い暴風雨</translation>
    </message>
    <message>
        <source>PM T-Storms</source>
        <translation>午後 雷雨</translation>
    </message>
    <message>
        <source>Thunderstorms</source>
        <translation>雷雨</translation>
    </message>
    <message>
        <source>Sunny/Windy</source>
        <translation>晴れ/強風</translation>
    </message>
    <message>
        <source>AM Thunderstorms</source>
        <translation>午前中 雷雨</translation>
    </message>
    <message>
        <source>AM Rain</source>
        <translation>午前中 雨</translation>
    </message>
    <message>
        <source>Iso T-Storms/Wind</source>
        <translation>一時雷雨/強風</translation>
    </message>
    <message>
        <source>Rain/Snow</source>
        <translation>雨/雪</translation>
    </message>
    <message>
        <source>Sct T-Storms/Wind</source>
        <translation>ときどき雷雨/強風</translation>
    </message>
    <message>
        <source>AM Showers/Wind</source>
        <translation>午前中 にわか雨/強風</translation>
    </message>
    <message>
        <source>Sct Snow Showers</source>
        <translation>ときどきにわか雪</translation>
    </message>
    <message>
        <source>Snow to Ice/Wind</source>
        <translation>雪のち氷/強風</translation>
    </message>
    <message>
        <source>Snow to Rain</source>
        <translation>雪のち雨</translation>
    </message>
    <message>
        <source>AM Light Rain</source>
        <translation>午前中 弱い雨</translation>
    </message>
    <message>
        <source>PM Light Rain</source>
        <translation>午後 弱い雨</translation>
    </message>
    <message>
        <source>PM Rain</source>
        <translation>午後 雨</translation>
    </message>
    <message>
        <source>Snow Showers</source>
        <translation>にわか雪</translation>
    </message>
    <message>
        <source>Rain to Snow</source>
        <translation>雨のち雪</translation>
    </message>
    <message>
        <source>PM Rain/Snow</source>
        <translation>午後 雨/雪</translation>
    </message>
    <message>
        <source>Few Showers/Wind</source>
        <translation>まれににわか雨/強風</translation>
    </message>
    <message>
        <source>Snow/Wind</source>
        <translation>雪/強風</translation>
    </message>
    <message>
        <source>PM Rain/Snow Showers</source>
        <translation>午後 にわか雨/にわか雪</translation>
    </message>
    <message>
        <source>PM Rain/Snow/Wind</source>
        <translation>午後 雨/雪/強風</translation>
    </message>
    <message>
        <source>Rain/Snow Showers/Wind</source>
        <translation>雨/にわか雪/強風</translation>
    </message>
    <message>
        <source>Rain/Snow/Wind</source>
        <translation>雨/雪/強風</translation>
    </message>
    <message>
        <source>Light Snow</source>
        <translation>弱い雪</translation>
    </message>
    <message>
        <source>PM Snow</source>
        <translation>午後 雪</translation>
    </message>
    <message>
        <source>Few Snow Showers/Wind</source>
        <translation>まれににわか雪/強風</translation>
    </message>
    <message>
        <source>Light Snow/Wind</source>
        <translation>弱い雪/強風</translation>
    </message>
    <message>
        <source>Wintry Mix</source>
        <translation>みぞれ</translation>
    </message>
    <message>
        <source>AM Wintry Mix</source>
        <translation>午前中 みぞれ</translation>
    </message>
    <message>
        <source>Hvy Rain/Freezing Rain</source>
        <translation>強い雨/氷雨</translation>
    </message>
    <message>
        <source>AM Light Snow</source>
        <translation>午前中 弱い雪</translation>
    </message>
    <message>
        <source>Rain/Freezing Rain</source>
        <translation>雨/氷雨</translation>
    </message>
    <message>
        <source>T-Storms/Wind</source>
        <translation>雷雨/強風</translation>
    </message>
    <message>
        <source>Sprinkles</source>
        <translation>小雨</translation>
    </message>
    <message>
        <source>AM Snow Showers</source>
        <translation>午前中にわか雪</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun/Wind</source>
        <translation>午前中 曇り/午後 晴れ/強風</translation>
    </message>
    <message>
        <source>AM Rain/Snow/Wind</source>
        <translation>午前中 雨/雪/強風</translation>
    </message>
    <message>
        <source>Rain to Snow/Wind</source>
        <translation>雨のち雪/強風</translation>
    </message>
    <message>
        <source>Snow to Wintry Mix</source>
        <translation>雪のちみぞれ</translation>
    </message>
    <message>
        <source>PM Snow Showers/Wind</source>
        <translation>午後 にわか雪/強風</translation>
    </message>
    <message>
        <source>Snow and Ice to Rain</source>
        <translation>雪と氷のち雨</translation>
    </message>
    <message>
        <source>Heavy Rain</source>
        <translation>強い雨</translation>
    </message>
    <message>
        <source>AM Rain/Ice</source>
        <translation>午前中 雨/氷</translation>
    </message>
    <message>
        <source>AM Snow Showers/Wind</source>
        <translation>午前中 にわか雪/強風</translation>
    </message>
    <message>
        <source>AM Light Snow/Wind</source>
        <translation>午前中 弱い雪/強風</translation>
    </message>
    <message>
        <source>PM Light Rain/Wind</source>
        <translation>午後 弱い雪/強風</translation>
    </message>
    <message>
        <source>AM Light Wintry Mix</source>
        <translation>午前中 弱いみぞれ</translation>
    </message>
    <message>
        <source>PM Light Snow/Wind</source>
        <translation>午後 弱い雪/強風</translation>
    </message>
    <message>
        <source>Heavy Rain/Wind</source>
        <translation>強い雨/強風</translation>
    </message>
    <message>
        <source>PM Snow Shower</source>
        <translation>午後 にわか雪</translation>
    </message>
    <message>
        <source>Snow to Rain/Wind</source>
        <translation>雪のち雨/強風</translation>
    </message>
    <message>
        <source>PM Light Rain/Ice</source>
        <translation>午後 弱い雨/氷</translation>
    </message>
    <message>
        <source>AM Snow</source>
        <translation>午前中 雪</translation>
    </message>
    <message>
        <source>Snow to Ice</source>
        <translation>雪のち氷</translation>
    </message>
    <message>
        <source>Wintry Mix/Wind</source>
        <translation>みぞれ/強風</translation>
    </message>
    <message>
        <source>PM Light Snow</source>
        <translation>午後 よわい雪</translation>
    </message>
    <message>
        <source>AM Drizzle</source>
        <translation>午前中 小雨</translation>
    </message>
    <message>
        <source>Strong Storms/Wind</source>
        <translation>強い暴風雨/強風</translation>
    </message>
    <message>
        <source>PM Drizzle</source>
        <translation>午後 小雨</translation>
    </message>
    <message>
        <source>Drizzle</source>
        <translation>小雨</translation>
    </message>
    <message>
        <source>AM Light Rain/Wind</source>
        <translation>午前中 弱い雨/強風</translation>
    </message>
    <message>
        <source>AM Rain/Wind</source>
        <translation>午前中 雨/強風</translation>
    </message>
    <message>
        <source>Wintry Mix to Snow</source>
        <translation>みぞれのち雪</translation>
    </message>
    <message>
        <source>Snow Showers/Windy</source>
        <translation>にわか雪/強風</translation>
    </message>
    <message>
        <source>Light Rain Shower</source>
        <translation>ときどき弱い雨</translation>
    </message>
    <message>
        <source>Light Rain with Thunder</source>
        <translation>雷を伴う弱い雨</translation>
    </message>
    <message>
        <source>Light Drizzle</source>
        <translation>霧雨</translation>
    </message>
    <message>
        <source>Mist</source>
        <translation>霧</translation>
    </message>
    <message>
        <source>Smoke</source>
        <translation>煙</translation>
    </message>
    <message>
        <source>Haze</source>
        <translation>もや</translation>
    </message>
    <message>
        <source>Light Snow Shower</source>
        <translation>ときどき弱い雪</translation>
    </message>
    <message>
        <source>Light Snow Shower/ Windy</source>
        <translation>ときどき弱い雪/強風</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>晴れ</translation>
    </message>
    <message>
        <source>A Few Clouds</source>
        <translation>わずかに雲</translation>
    </message>
    <message>
        <source>Fair</source>
        <translation>快晴</translation>
    </message>
</context>
<context>
    <name>String::WindDirection</name>
    <message>
        <source>N</source>
        <translation>北</translation>
    </message>
    <message>
        <source>NNE</source>
        <translation>北北東</translation>
    </message>
    <message>
        <source>NE</source>
        <translation>北東</translation>
    </message>
    <message>
        <source>E</source>
        <translation>東</translation>
    </message>
    <message>
        <source>SE</source>
        <translation>南東</translation>
    </message>
    <message>
        <source>SSE</source>
        <translation>南南東</translation>
    </message>
    <message>
        <source>S</source>
        <translation>南</translation>
    </message>
    <message>
        <source>SSW</source>
        <translation>南南西</translation>
    </message>
    <message>
        <source>SW</source>
        <translation>南西</translation>
    </message>
    <message>
        <source>W</source>
        <translation>西</translation>
    </message>
    <message>
        <source>NW</source>
        <translation>北西</translation>
    </message>
    <message>
        <source>NNW</source>
        <translation>北北西</translation>
    </message>
    <message>
        <source>ENE</source>
        <translation>東北東</translation>
    </message>
    <message>
        <source>ESE</source>
        <translation>東南東</translation>
    </message>
    <message>
        <source>WSW</source>
        <translation>西南西</translation>
    </message>
    <message>
        <source>WNW</source>
        <translation>西北西</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>loading...</source>
        <translation>ロード中...</translation>
    </message>
    <message>
        <source>[ retrieving weather data ... ]</source>
        <translation>[ 気象データ受信中... ]</translation>
    </message>
    <message>
        <source>current conditions</source>
        <translation>現在の様子</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>湿度</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>気圧</translation>
    </message>
    <message>
        <source>Wind</source>
        <translation>風</translation>
    </message>
    <message>
        <source>Visibility</source>
        <translation>視界</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>体感温度</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>紫外線指数</translation>
    </message>
    <message>
        <source>extended forecast</source>
        <translation>明後日以降の天気</translation>
    </message>
    <message>
        <source>LO</source>
        <translation>最低</translation>
    </message>
    <message>
        <source>HI</source>
        <translation>最高</translation>
    </message>
    <message>
        <source>today&apos;s forecast</source>
        <translation>今日の天気</translation>
    </message>
    <message>
        <source>tomorrow&apos;s outlook</source>
        <translation>明日の概況</translation>
    </message>
    <message>
        <source>Forecast for</source>
        <translation>明日は：</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>レーダー画像</translation>
    </message>
    <message>
        <source>Map Unavailable</source>
        <translation>地図データがありません</translation>
    </message>
    <message>
        <source>RAIN</source>
        <translation>雨</translation>
    </message>
    <message>
        <source>MIX/ICE</source>
        <translation>みぞれ/雹</translation>
    </message>
    <message>
        <source>SNOW</source>
        <translation>雪</translation>
    </message>
    <message>
        <source>LIGHT</source>
        <translation>弱い</translation>
    </message>
    <message>
        <source>HEAVY</source>
        <translation>強い</translation>
    </message>
    <message>
        <source>Enter Zip Code</source>
        <translation>郵便番号</translation>
    </message>
    <message>
        <source>weather setup</source>
        <translation>気象情報の設定</translation>
    </message>
    <message>
        <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
        <translation>保存するには &apos;i&apos;,キャンセルするには Esc を押してください</translation>
    </message>
    <message>
        <source>COLD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COLDEST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CLOUD TEMPERATURE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Weather</name>
    <message>
        <source> is invalid)</source>
        <translation>は無効)</translation>
    </message>
    <message>
        <source>   No Location Set, Please read the README</source>
        <translation>地域が設定されていません。READMEを読んでください。</translation>
    </message>
    <message>
        <source>Configuring MythWeather...</source>
        <translation>MythWeatherを設定中...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select unit conversion...</source>
        <translation>右矢印キーで単位を変更...</translation>
    </message>
    <message>
        <source>Weather Units</source>
        <translation>単位</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>地域</translation>
    </message>
    <message>
        <source>Aggressiveness</source>
        <translation>接続</translation>
    </message>
    <message>
        <source>Configuration Saved...</source>
        <translation>保存されました...</translation>
    </message>
    <message>
        <source>Retrieving weather data...</source>
        <translation>気象データを受信中...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select your location...</source>
        <translation>右矢印キーで地域を選択...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select the aggressiveness level...</source>
        <translation>右矢印キーで接続レベル選択...</translation>
    </message>
    <message>
        <source> 1  High Speed Connection</source>
        <translation>1  高速接続</translation>
    </message>
    <message>
        <source> 8  Medium Speed Connection</source>
        <translation>8  中速接続</translation>
    </message>
    <message>
        <source> 15 Low Speed Connection</source>
        <translation>15 低速接続</translation>
    </message>
    <message>
        <source>Obtaining initial weather data...</source>
        <translation>初期気象データを取得中...</translation>
    </message>
    <message>
        <source>Updating weather data...</source>
        <translation>気象データを更新中...</translation>
    </message>
    <message>
        <source>Calm</source>
        <translation>無風</translation>
    </message>
    <message>
        <source> at </source>
        <translation>の風 </translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>良好</translation>
    </message>
    <message>
        <source> (minimal)</source>
        <translation>(最小)</translation>
    </message>
    <message>
        <source> (moderate)</source>
        <translation>(普通)</translation>
    </message>
    <message>
        <source> (high)</source>
        <translation>(高い)</translation>
    </message>
    <message>
        <source> (extreme)</source>
        <translation>(最大)</translation>
    </message>
    <message>
        <source>Today a high of </source>
        <translation>今日の最高気温は</translation>
    </message>
    <message>
        <source> and a low of </source>
        <translation>°C、最低は</translation>
    </message>
    <message>
        <source>. Currently there is a humidity of </source>
        <translation>. 現在の湿度は</translation>
    </message>
    <message>
        <source>% and the winds are</source>
        <translation>% 風は</translation>
    </message>
    <message>
        <source> calm.</source>
        <translation>無風.</translation>
    </message>
    <message>
        <source> coming in at </source>
        <translation>から</translation>
    </message>
    <message>
        <source> mph from the </source>
        <translation>mph から</translation>
    </message>
    <message>
        <source> Km/h from the </source>
        <translation>Km/h から</translation>
    </message>
    <message>
        <source> Visibility will be unlimited for today.</source>
        <translation>本日の視界は明瞭.</translation>
    </message>
    <message>
        <source> Visibility conditions are unknown.</source>
        <translation>視界の状態は不明.</translation>
    </message>
    <message>
        <source> There will be a visibility of </source>
        <translation>視界の状態は</translation>
    </message>
    <message>
        <source> miles.</source>
        <translation>マイル.</translation>
    </message>
    <message>
        <source> km.</source>
        <translation>キロメートル.</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>日曜日</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>月曜日</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>火曜日</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>水曜日</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>木曜日</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>金曜日</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>土曜日</translation>
    </message>
    <message>
        <source>Date Error</source>
        <translation>日付エラー</translation>
    </message>
    <message>
        <source>Tomorrow expect a high of </source>
        <translation>予想気温は最高で</translation>
    </message>
    <message>
        <source>Expected conditions: </source>
        <translation>お天気は </translation>
    </message>
    <message>
        <source>Weather data from: </source>
        <translation>気象データ: </translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>更新中...</translation>
    </message>
    <message>
        <source> (Not All Information Available)</source>
        <translation>(一部の情報は取得できません)</translation>
    </message>
    <message>
        <source>*** Invalid Area ID or Server Error ***</source>
        <translation>*** 不正な地域IDまたはサーバーエラー ***</translation>
    </message>
    <message>
        <source>Imperial (Fahrenheit, in, etc)</source>
        <translation>華氏、インチ等</translation>
    </message>
    <message>
        <source>Metric (Celsius, kPa, etc)</source>
        <translation>摂氏、キロパスカル等</translation>
    </message>
    <message>
        <source> F</source>
        <translation>°F</translation>
    </message>
    <message>
        <source> C</source>
        <translation>°C</translation>
    </message>
    <message>
        <source>.</source>
        <translation>°C.</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source> - PAUSED -</source>
        <translation>- 一時停止 -</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation type="unfinished">レーダー画像</translation>
    </message>
    <message>
        <source>satellite image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
